package cn.estsh.i3plus.core.apiservice.controller.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysLogOperateService;
import cn.estsh.i3plus.platform.common.util.PlatformConstWords;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.platform.platbean.SysLogOperate;
import cn.estsh.impp.framework.base.controller.CoreBaseController;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.websocket.server.PathParam;
import java.util.List;

/**
 * @Description : 操作日志服务
 * @Reference :
 * @Author : yunhao
 * @Date : 2018-10-25 14:08
 * @Modify :
 **/
@RestController
@Api(description = "操作日志")
@RequestMapping(PlatformConstWords.BASE_URL + "/sys-log-operate")
public class SysLogOperateController extends CoreBaseController {
    public static final Logger LOGGER = LoggerFactory.getLogger(SysLogOperateController.class);

    @Autowired
    private ISysLogOperateService logOperateService;

    @PostMapping(value = "/insert")
    @ApiOperation(value = "添加操作日志",notes = "添加操作日志")
    public ResultBean insertSysLogOperateController(SysLogOperate logOperate){
        try {
            logOperateService.insertSysLogOperate(logOperate);
            return ResultBean.success("添加成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @DeleteMapping(value = "/delete")
    @ApiOperation(value = "根据id删除操作日志",notes = "根据id删除操作日志")
    public ResultBean deleteSysLogOperateById(String id){
        try {
            // 条件验证
            ValidatorBean.checkNotNull(id,"id不能为空！");

            logOperateService.deleteSysLogOperateById(Long.parseLong(id));
            return ResultBean.success("删除成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping(value = "/list")
    @ApiOperation(value = "查询全部操作日志",notes = "查询全部操作日志")
    public ResultBean findSysLogOperateAll(){
        try {
            List logOperateList = logOperateService.listSysLogOperate();
            return ResultBean.success("查询成功").setResultList(logOperateList).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping(value = "/get/{id}")
    @ApiOperation(value = "根据id查询操作日志",notes = "根据id查询操作日志")
    public ResultBean getSysLogOperateById(@PathParam("id") String id){
        try{
            SysLogOperate logOperate = logOperateService.getSysLogOperateById(Long.parseLong(id));
            if (logOperate != null) {
                return ResultBean.success("查询成功")
                        .setResultObject(logOperate)
                        .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
            }else {
                return ResultBean.fail("操作日志不存在")
                        .setCode(ResourceEnumUtil.MESSAGE.EMPTY.getCode());
            }
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping(value = "/query")
    @ApiOperation(value = "操作日志复杂查询，分页，排序",notes = "操作日志复杂查询，分页，排序")
    public ResultBean querySysLogOperateByPager(SysLogOperate logOperate, Pager pager){
        try {
            ListPager logSystemList = logOperateService.querySysLogOperateByPager(logOperate, pager);
            return ResultBean.success("查询成功").setListPager(logSystemList).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }
}
